#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-KhhoH17vi5B8jXrqdLCkEV
key:                  network-multicast-0.3.2-KhhoH17vi5B8jXrqdLCkEV
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  c73b9db3959166bbf77ca6156b65492b
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-KhhoH17vi5B8jXrqdLCkEV
depends:
    base-4.18.2.1 network-3.1.4.0-LsWsY6caX6uCNLTGwySDR3
    network-bsd-2.8.1.0-D7SZrPYxhMR2DXknTcXx6t

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

